/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mouse Gesture for Mozilla.
 *
 * The Initial Developer of the Original Code is Pavol Vaskovic.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Andy Edmonds <aedmonds@mindspring.com> 
 *  Pavol Vaskovic <pali@pali.sk>
 *  Steve Kangas <bookmarklets.com> FIXME  email
 *  Squarefree.com     FIXME who exactly: whole name, email
 *  Scurrie            FIXME whole name, email
 *  Exotrip            FIXME whole name, email
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
    U      Function processCoordinates returns in global variable 'gesture' 
    |      list of 4-directional movements made in gesture. Function fireGesture 
R---x---L  takes compacted 4dir chain code and fires the desired action.
    |      Ex. "DL" means that user has moved mouse down, then left
    D          "LRL" was gesture right-left-right etc.
**/    

function fireGesture(aGesture){
  var tab, curTab, curTabNum, nextTab, l, i, tempW;
  switch(aGesture){

// *** navigational gestures (& related) ***

    case "L" :
      if(mozgestDebug)  mozgestDebugText("Previous document in history (BACK)");
      window.status="Previous document in history (BACK)";
      BrowserBack();
      break;

    case "R" :
      if(mozgestDebug)  mozgestDebugText("Next document in history (FORWARD)");
      window.status="Next document in history (FORWARD)";
      BrowserForward();
      break;

    case "UD" :
      if(mozgestDebug) mozgestDebugText("Reload document");
      window.status="Reload document";
      BrowserReload();
      break;

    case "UDU" :
      if(mozgestDebug) mozgestDebugText("Force Reload document");
      window.status="Force Reload document";
      BrowserReloadSkipCache();
      break;

    case "DURD":
      if(mozgestDebug) mozgestDebugText("Load Home Page");
      window.status="Load Home Page";
      BrowserHome();
      break;

    case "D" :
      if(mozgestDebug) mozgestDebugText("Open new document");
      window.status="Open new document";
      if(!globalOnLink) { 
        var uriToLoad = "";
        if (pref && pref.GetIntPref("browser.startup.page") == 1)
         uriToLoad = getHomePage();
        openDialog(getBrowserURL(),"_blank","chrome,all,dialog=no",uriToLoad);
      }
      else { tempW = window.open(globalOnLink[0]);}
      break;			

    case "DU" :
      if(mozgestDebug)  mozgestDebugText("Duplicate window");
      window.status="Duplicate window";
      tempW = window.open(window._content.document.location,'newWin');
      break;

    case "ULU" :  // from bookmarklets.com
      if(mozgestDebug)  mozgestDebugText("Up a directory in URLspace");
      window.status="Up a directory in URLspace";
      var aUrl = window._content.document.location.href;
      aUrl = aUrl.substring(0, aUrl.substring(0, aUrl.length-1).lastIndexOf('/')+1);
      window._content.document.location.href = aUrl;
      break;

   case "URD" :
      if(mozgestDebug)  mozgestDebugText("View Source");
      window.status="View Source";
      BrowserViewSource();
      break;

    case "LDRDL" :
      if(mozgestDebug)  mozgestDebugText("View Source");
      window.status="View Source";
      BrowserViewSource();
      break;  

    case "LDR":  // Contributed by Squarefree.com
      if(mozgestDebug)  mozgestDebugText("View Cookies");
      window.status="View Cookies";
      if (window._content.document.cookie)
        alert('Cookies stored by this host or domain:\n\n'
          + window._content.document.cookie.replace(/; /g,'\n'));
      else
        alert("No cookies are set for this host or domain.")
      break;

    case "URDURD":  // By aedmonds
      if(mozgestDebug) mozgestDebugText("Show Meta Info");
      window.status="Show Meta Info";
      var metas = window._content.document.getElementsByTagName("meta");
      if (metas.length != 0){
        var metastr = "Meta Tags: \n\n";
        for(var ameta = 0; ameta < metas.length; ameta++) {
          var mymeta = metas.item(ameta);
          metastr += "<META ";
          if (mymeta.name) metastr += "name=\"" + mymeta.name + "\" ";
          if (mymeta.httpEquiv)
            metastr+= "http-equiv=\"" + mymeta.httpEquiv + "\" ";
          if (mymeta.content) metastr += "content=\"" + mymeta.content + "\" ";
          if (mymeta.scheme) metastr += "scheme=\"" + mymeta.scheme + "\" ";
          metastr += '>\n';
        }
        alert(metastr);
      }
      else alert("There is no Meta information on this page.");
      break;

// *** tab gestures ***

    case "DULR" : // Contributed by Exotrip
      if(mozgestDebug)  mozgestDebugText("New browser tab");
      window.status="New browser tab";
      BrowserOpenTab();
      break;
	  
    case "DUD" :
      if(mozgestDebug)  mozgestDebugText("Duplicate tab");
      window.status="Duplicate tab";
      delayedOpenTab(window._content.document.location);
      break;

    case "DUR" : //Contributed by Scurrie
      if(mozgestDebug) mozgestDebugText("Next Tab");
      window.status = "Next Tab";
      if (getBrowser().mTabContainer.childNodes.length > 1){
        l = getBrowser().mTabContainer.childNodes.length;
        curTab = getBrowser().selectedTab;
        for (i = 0; i < l; i++){
          tab = getBrowser().mTabContainer.childNodes[i];
          if (tab == curTab) {curTabNum = i;}
        }
        if (curTabNum == getBrowser().mTabContainer.childNodes.length-1){
          nextTab = getBrowser().mTabContainer.childNodes[0];
        }
        else {
          mozgestDebugText(curTabNum);
          nextTab = getBrowser().mTabContainer.childNodes[curTabNum+1]; 
        }
        getBrowser().selectedTab = nextTab;
      }
      break;

    case "DUL" : //Contributed by Scurrie
      if(mozgestDebug) mozgestDebugText("Previous Tab");
      window.status = "Previous Tab";
      if (getBrowser().mTabContainer.childNodes.length > 1){
        l = getBrowser().mTabContainer.childNodes.length;
        curTab = getBrowser().selectedTab;
        for (i = 0; i < l; i++){
          tab = getBrowser().mTabContainer.childNodes[i];
          if (tab == curTab) {curTabNum = i;}
        }
        if (curTabNum == 0){
          curTabNum = getBrowser().mTabContainer.childNodes.length -1;
          nextTab = getBrowser().mTabContainer.childNodes[curTabNum];
        }
        else {
        nextTab = getBrowser().mTabContainer.childNodes[curTabNum-1];}
        getBrowser().selectedTab = nextTab;
      }
      break;

// *** window manipulation (minimize etc.) - see bugzilla bug 30529 ***

    case "UR" :
      if(mozgestDebug) mozgestDebugText("Restore or maximize window");
      window.status="Restore or maximize window";
      window.moveTo(0,0);
      window.resizeTo(screen.availWidth, screen.availHeight);
      break;

    case "DL" :
      mozgestDebugText("Minimize window");
      window.status="Minimize window";
      break;

    case "RLR" :
      if(mozgestDebug)  mozgestDebugText("Close document [1]");
      window.status="Close document [1]";
      if (getBrowser().mTabContainer.childNodes.length > 1)
        getBrowser().removeCurrentTab();
      else window.setTimeout("window.close()", 10); 
      break;

    case "DR" :
      if(mozgestDebug)  mozgestDebugText("Close document [2]");
      window.status="Close document [2]";
      if (getBrowser().mTabContainer.childNodes.length > 1)
        getBrowser().removeCurrentTab();
      else window.setTimeout("window.close()", 10);
      break;

// *** misc *** 

    case "RLDUR":
      myBod = window._content.document.body;
      myBod.background='http://www.surfmind.com/images/explode.gif';
      myBod.setAttribute("style", "background:url(http://www.surfmind.com/images/explode.gif)");
      break;

// *** link drag over gestures ***

    case "UL":
      if(mozgestDebug)
        mozgestDebugText("Double stack first link in gesture in new window");
      window.status="Double stack first link in gesture in new window";
      if(globalOnLink) mozgestStack(globalOnLink[0]);
      break;

    case "U":
      if(mozgestDebug)
        mozgestDebugText("Load Link in New Tab");
      window.status="Load Link in New Tab";
      if(globalOnLink) delayedOpenTab(globalOnLink[0]);
      break;

    default:  
      if(globalOnLink) {
        lastgesture = gesture.join("");
        if(mozgestDebug) mozgestDebugText("Multiple link spawn: " + lastgesture
          + ' spotted... \n  ...Looking for Finishing Move');
        if(lastgesture.substr(lastgesture.length-2,2) == "RU") {
          if(mozgestDebug) mozgestDebugText("Opening links in windows")
          for(var lnks = 0; lnks < globalOnLink.length; lnks++) {
            tempW = window.open(globalOnLink[lnks]);
          }
        }
        if(lastgesture.substr(lastgesture.length-3,3) == "RUL") {
          if(mozgestDebug) mozgestDebugText("Opening links in tabs")
          for(var lnks = 0; lnks < globalOnLink.length; lnks++) {
            delayedOpenTab(globalOnLink[lnks]);
          }
        }
      }
      else {
        if(mozgestDebug) mozgestDebugText("Unknown Gesture");
        window.status="Unknown Gesture: " + aGesture;
      }
  } // end switch
} // end function fireGesture()
